import {useErrorStore} from '@/stores/error';
import type {
  AddViewConfig,
  FormValues,
  SchoolClassDetailResponseModel,
} from '../models';
import {fetchAuthenticated} from '../retrieveData';
import {getDetailResponseModelMocked, getError, getSaveError, type SaveError} from '@/helpers/dataAccess';
import i18next from 'i18next';


// eslint-disable-next-line
export const fetchSchoolClassAddViewConfig = async(): Promise<AddViewConfig> => {
  console.log('Not implemented');
  return {
    pages: [],
  };
};

// eslint-disable-next-line
export const createSchoolClass = async(values: FormValues): Promise<SaveError | null> => {
  console.log('Not implemented');
  return null;
};

const fetchSchoolClassMocked = (): SchoolClassDetailResponseModel => {
  const schoolClass: SchoolClassDetailResponseModel = getDetailResponseModelMocked();
  console.debug('mock school class', schoolClass);
  return schoolClass;
};

export const fetchSchoolClass = async(schoolClass: string): Promise<SchoolClassDetailResponseModel | null> => {
  if (import.meta.env.VITE_USE_REAL_BACKEND !== 'true') {
    console.debug('fetchSchoolClass. VITE_USE_REAL_BACKEND===false in DEV mode. Returning mock data');
    return new Promise(resolve => {
      setTimeout(() => {
        resolve(fetchSchoolClassMocked());
      }, 1000);
    });
  }

  const answer = await fetchAuthenticated(`/ucsschool/bff-groups/v1/groups/school_class/detail/${schoolClass}`);
  if (answer.status === 404) {
    return null;
  }
  const error = await getError(answer);
  if (error) {
    const errorStore = useErrorStore();
    const title = i18next.t('dataAccess.fetchGroup.error.title', {context: 'school_class'});
    errorStore.push({
      title,
      message: JSON.stringify(error.detail),
    });
    return Promise.reject(answer);
  }
  return await answer.json();
};

export const updateSchoolClass = async(url: string, values: FormValues): Promise<SaveError | null> => {
  if (import.meta.env.VITE_USE_REAL_BACKEND !== 'true') {
    console.debug('updateSchoolClass. VITE_USE_REAL_BACKEND===false in DEV mode. Returning mock data');
    // TODO have the fail case in some way too
    return new Promise(resolve => {
      setTimeout(() => {
        resolve(null);
      }, 1000);
    });
  }

  const fixedProtocolUrl = url.replace(/https?:/, location.protocol).replace('detail/', '');
  const answer = await fetchAuthenticated(`${fixedProtocolUrl}`, {
    method: 'PATCH',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(values),
  });
  return await getSaveError(answer, 'createWorkgroup');
};
